summaryrefslogtreecommitdiff
path: root/sw/source/core/inc/flowfrm.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/inc/flowfrm.hxx')
-rw-r--r--sw/source/core/inc/flowfrm.hxx118
1 files changed, 59 insertions, 59 deletions
diff --git a/sw/source/core/inc/flowfrm.hxx b/sw/source/core/inc/flowfrm.hxx
index d94bd5e9fda5..86771b5bc56f 100644
--- a/sw/source/core/inc/flowfrm.hxx
+++ b/sw/source/core/inc/flowfrm.hxx
@@ -22,66 +22,66 @@
#include "frmtool.hxx"
-class SwPageFrm;
+class SwPageFrame;
class SwRect;
class SwBorderAttrs;
class SwDoc;
class SwNodeIndex;
// #i44049#
-class SwObjectFormatterTextFrm;
+class SwObjectFormatterTextFrame;
/** Base class that provides the general functionalities for frames that are
allowed at page breaks (flow) and shall continue on the next page (can be
- split), e.g. paragraphs (ContentFrm) or tables (TabFrm).
+ split), e.g. paragraphs (ContentFrame) or tables (TabFrame).
- Some parts of these functionalities are implemented in FlowFrm while the
- specific ones are done in the corresponding Frm classes. The FlowFrm has to
- be seen as a base class. As such it is no Frm by itself and thus no direct
- instances of FlowFrm can exist.
+ Some parts of these functionalities are implemented in FlowFrame while the
+ specific ones are done in the corresponding Frame classes. The FlowFrame has to
+ be seen as a base class. As such it is no Frame by itself and thus no direct
+ instances of FlowFrame can exist.
- Actually it is not even a real Frm. The obvious implementation would be a
- FlowFrm that is virtually inherited from SwFrm and that works with its own
- member data. Further classes would need to inherit from FlowFrm and (via
+ Actually it is not even a real Frame. The obvious implementation would be a
+ FlowFrame that is virtually inherited from SwFrame and that works with its own
+ member data. Further classes would need to inherit from FlowFrame and (via
multiple base classes since the class tree splits exactly at the branch
- from SwFrm to SwContentFrm and SwLayoutFrm) also virtually from SwFrm as
+ from SwFrame to SwContentFrame and SwLayoutFrame) also virtually from SwFrame as
well. Unfortunately, this leads - besides problems with compilers and
debugging programs - to high additional costs, that we IMHO are not able to
afford nowadays.
- Hence, we use another technique: A FlowFrm keeps a reference to a SwFrm
+ Hence, we use another technique: A FlowFrame keeps a reference to a SwFrame
- which it is actually itself - and they are friends. As a result, the
- FlowFrm can work with the reference to the SwFrm instead of working with
+ FlowFrame can work with the reference to the SwFrame instead of working with
its own this-pointer.
*/
-class SwFlowFrm
+class SwFlowFrame
{
// PrepareMake is allowed to lock/unlock (robustness)
- friend inline void PrepareLock ( SwFlowFrm * );
- friend inline void PrepareUnlock( SwFlowFrm * );
- friend inline void TableSplitRecalcLock( SwFlowFrm * );
- friend inline void TableSplitRecalcUnlock( SwFlowFrm * );
+ friend inline void PrepareLock ( SwFlowFrame * );
+ friend inline void PrepareUnlock( SwFlowFrame * );
+ friend inline void TableSplitRecalcLock( SwFlowFrame * );
+ friend inline void TableSplitRecalcUnlock( SwFlowFrame * );
// #i44049#
- friend class SwObjectFormatterTextFrm;
- friend class FlowFrmJoinLockGuard;
+ friend class SwObjectFormatterTextFrame;
+ friend class FlowFrameJoinLockGuard;
// TableSel is allowed to reset the follow-bit
- friend inline void UnsetFollow( SwFlowFrm *pFlow );
+ friend inline void UnsetFollow( SwFlowFrame *pFlow );
- friend void MakeFrms( SwDoc *, const SwNodeIndex &, const SwNodeIndex & );
+ friend void MakeFrames( SwDoc *, const SwNodeIndex &, const SwNodeIndex & );
friend class SwNode2LayImpl;
- SwFrm& m_rThis;
+ SwFrame& m_rThis;
// helper methods for MoveSubTree()
- static SwLayoutFrm *CutTree( SwFrm* );
- static bool PasteTree( SwFrm *, SwLayoutFrm *, SwFrm *, SwFrm* );
+ static SwLayoutFrame *CutTree( SwFrame* );
+ static bool PasteTree( SwFrame *, SwLayoutFrame *, SwFrame *, SwFrame* );
/** indicates that a backward move was done over multiple pages
Needed for the interaction of _GetPrevxxx and MoveBwd so that multiple
pages can be skipped at the same time. In addition, it is evaluated by
- the MoveBwd() method in TabFrm.
+ the MoveBwd() method in TabFrame.
*/
static bool m_bMoveBwdJump;
@@ -90,18 +90,18 @@ class SwFlowFrm
#i11860#
- @param _pProposedPrevFrm
+ @param _pProposedPrevFrame
optional input parameter - pointer to frame, which should be used
instead of the direct previous frame.
*/
- const SwFrm* _GetPrevFrmForUpperSpaceCalc( const SwFrm* _pProposedPrevFrm = nullptr ) const;
+ const SwFrame* _GetPrevFrameForUpperSpaceCalc( const SwFrame* _pProposedPrevFrame = nullptr ) const;
/** method to detemine the upper space amount, which is considered for
the previous frame
#i11860#
*/
- SwTwips _GetUpperSpaceAmountConsideredForPrevFrm() const;
+ SwTwips _GetUpperSpaceAmountConsideredForPrevFrame() const;
/** method to detemine the upper space amount, which is considered for
the page grid
@@ -112,8 +112,8 @@ class SwFlowFrm
const SwTwips _nUpperSpaceWithoutGrid ) const;
protected:
- SwFlowFrm *m_pFollow;
- SwFlowFrm *m_pPrecede;
+ SwFlowFrame *m_pFollow;
+ SwFlowFrame *m_pPrecede;
bool m_bLockJoin :1; // if true than joins (and thus deletes) are prohibited!
bool m_bUndersized:1; // I am smaller than needed
@@ -122,17 +122,17 @@ protected:
// checks if forward flow makes sense to prevent infinite moves
inline bool IsFwdMoveAllowed();
// #i44049# - method <CalcContent(..)> has to check this property.
- friend void CalcContent( SwLayoutFrm *pLay, bool bNoColl, bool bNoCalcFollow );
+ friend void CalcContent( SwLayoutFrame *pLay, bool bNoColl, bool bNoCalcFollow );
bool IsKeepFwdMoveAllowed(); // like above, forward flow for Keep.
/** method to determine overlapping of an object that requests floating
0: no overlapping
- 1: objects that are anchored at the FlowFrm overlap
+ 1: objects that are anchored at the FlowFrame overlap
2: objects that are anchored somewhere else overlap
3: both types of objects overlap
*/
- sal_uInt8 BwdMoveNecessary( const SwPageFrm *pPage, const SwRect &rRect );
+ sal_uInt8 BwdMoveNecessary( const SwPageFrame *pPage, const SwRect &rRect );
void LockJoin() { m_bLockJoin = true; }
void UnlockJoin() { m_bLockJoin = false; }
@@ -140,14 +140,14 @@ protected:
bool CheckMoveFwd( bool& rbMakePage, bool bKeep, bool bMovedBwd );
bool MoveFwd( bool bMakePage, bool bPageBreak, bool bMoveAlways = false );
bool MoveBwd( bool &rbReformat );
- virtual bool ShouldBwdMoved( SwLayoutFrm *pNewUpper, bool bHead, bool &rReformat )=0;
+ virtual bool ShouldBwdMoved( SwLayoutFrame *pNewUpper, bool bHead, bool &rReformat )=0;
public:
- SwFlowFrm( SwFrm &rFrm );
- virtual ~SwFlowFrm();
+ SwFlowFrame( SwFrame &rFrame );
+ virtual ~SwFlowFrame();
- const SwFrm& GetFrm() const { return m_rThis; }
- SwFrm& GetFrm() { return m_rThis; }
+ const SwFrame& GetFrame() const { return m_rThis; }
+ SwFrame& GetFrame() { return m_rThis; }
static bool IsMoveBwdJump() { return m_bMoveBwdJump; }
static void SetMoveBwdJump( bool bNew ){ m_bMoveBwdJump = bNew; }
@@ -158,17 +158,17 @@ public:
bool IsPrevObjMove() const;
/** hook tree onto new parent with minimal operations and notifications */
- void MoveSubTree( SwLayoutFrm* pParent, SwFrm* pSibling = nullptr );
+ void MoveSubTree( SwLayoutFrame* pParent, SwFrame* pSibling = nullptr );
bool HasFollow() const { return m_pFollow != nullptr; }
bool IsFollow() const { return nullptr != m_pPrecede; }
- bool IsAnFollow( const SwFlowFrm *pFlow ) const;
- const SwFlowFrm *GetFollow() const { return m_pFollow; }
- SwFlowFrm *GetFollow() { return m_pFollow; }
- void SetFollow(SwFlowFrm *const pFollow);
+ bool IsAnFollow( const SwFlowFrame *pFlow ) const;
+ const SwFlowFrame *GetFollow() const { return m_pFollow; }
+ SwFlowFrame *GetFollow() { return m_pFollow; }
+ void SetFollow(SwFlowFrame *const pFollow);
- const SwFlowFrm *GetPrecede() const { return m_pPrecede; }
- SwFlowFrm *GetPrecede() { return m_pPrecede; }
+ const SwFlowFrame *GetPrecede() const { return m_pPrecede; }
+ SwFlowFrame *GetPrecede() { return m_pPrecede; }
bool IsJoinLocked() const { return m_bLockJoin; }
bool IsAnyJoinLocked() const { return m_bLockJoin || HasLockedFollow(); }
@@ -191,7 +191,7 @@ public:
optional input parameter - consider the page grid while calculating?
*/
SwTwips CalcUpperSpace( const SwBorderAttrs *pAttrs = nullptr,
- const SwFrm* pPr = nullptr,
+ const SwFrame* pPr = nullptr,
const bool _bConsiderGrid = true ) const;
/** method to determine the upper space amount, which is considered for
@@ -200,7 +200,7 @@ public:
#i11860#
*/
- SwTwips GetUpperSpaceAmountConsideredForPrevFrmAndPageGrid() const;
+ SwTwips GetUpperSpaceAmountConsideredForPrevFrameAndPageGrid() const;
/** calculation of lower space */
SwTwips CalcLowerSpace( const SwBorderAttrs* _pAttrs = nullptr ) const;
@@ -225,31 +225,31 @@ public:
void SetFlyLock( bool bNew ){ m_bFlyLock = bNew; }
bool IsFlyLock() const { return m_bFlyLock; }
// Casting of a Frm into a FlowFrm (if it is one, otherwise 0)
// These methods need to be customized in subclasses!
- static SwFlowFrm *CastFlowFrm( SwFrm *pFrm );
- static const SwFlowFrm *CastFlowFrm( const SwFrm *pFrm );
+ static SwFlowFrame *CastFlowFrame( SwFrame *pFrame );
+ static const SwFlowFrame *CastFlowFrame( const SwFrame *pFrame );
};
-inline bool SwFlowFrm::IsFwdMoveAllowed()
+inline bool SwFlowFrame::IsFwdMoveAllowed()
{
return m_rThis.GetIndPrev() != nullptr;
}
//use this to protect a SwLayoutFrm for a given scope from getting merged with
//its neighbour and thus deleted
-class FlowFrmJoinLockGuard
+class FlowFrameJoinLockGuard
{
private:
- SwFlowFrm *m_pFlow;
+ SwFlowFrame *m_pFlow;
bool m_bOldJoinLocked;
public:
//JoinLock pParent for the lifetime of the Cut/Paste call, etc. to avoid
//SwSectionFrm::MergeNext removing the pParent we're trying to reparent
//into
- FlowFrmJoinLockGuard(SwLayoutFrm* pFrm)
+ FlowFrameJoinLockGuard(SwLayoutFrame* pFrame)
{
- m_pFlow = SwFlowFrm::CastFlowFrm(pFrm);
+ m_pFlow = SwFlowFrame::CastFlowFrame(pFrame);
if (m_pFlow)
{
m_bOldJoinLocked = m_pFlow->IsJoinLocked();
@@ -261,7 +261,7 @@ public:
}
}
- ~FlowFrmJoinLockGuard()
+ ~FlowFrameJoinLockGuard()
{
if (m_pFlow && !m_bOldJoinLocked)
m_pFlow->UnlockJoin();
@@ -225,31 +225,31 @@ public:
void SetFlyLock( bool bNew ){ m_bFlyLock = bNew; }
bool IsFlyLock() const { return m_bFlyLock; }
- // Casting of a Frm into a FlowFrm (if it is one, otherwise 0)
+ // Casting of a Frame into a FlowFrame (if it is one, otherwise 0)
// These methods need to be customized in subclasses!
@@ -225,31 +225,31 @@ public:
return m_rThis.GetIndPrev() != nullptr;
}
-//use this to protect a SwLayoutFrm for a given scope from getting merged with
+//use this to protect a SwLayoutFrame for a given scope from getting merged with
//its neighbour and thus deleted
@@ -225,31 +225,31 @@ public:
public:
//JoinLock pParent for the lifetime of the Cut/Paste call, etc. to avoid
- //SwSectionFrm::MergeNext removing the pParent we're trying to reparent
+ //SwSectionFrame::MergeNext removing the pParent we're trying to reparent
//into